@@ -12,9 +12,6 @@ int isa_port_base  = IOP_ADDR;
 
 #include <fcntl.h>
 #include <unistd.h>
-#ifdef NETBSD
-#include <machine/pio.h>
-#endif
 
 #include "io_static.c"
 
@@ -26,7 +23,7 @@ static int ReadByte(int addr)
 {
 	int ret;
 	OUTb(INDEX_REG_PORT, addr); WAIT;
-	ret = inb(DATA_PORT); WAIT;
+	ret = INb(DATA_PORT); WAIT;
 	return (ret & 0xFF);
 }
 
@@ -40,7 +37,7 @@ static int ReadWord(int addr)
 {
 	int ret;
 	OUTb(INDEX_REG_PORT, addr); WAIT;
-	ret = inw(DATA_PORT); WAIT;
+	ret = INw(DATA_PORT); WAIT;
 	return (ret & 0xFFFF);
 }
 
