@@ -13,9 +13,6 @@ int  viahwm_base = -1;
 #include <stdio.h>
 #include <fcntl.h>
 #include <unistd.h>
-#ifdef NETBSD
-#include <machine/pio.h>
-#endif
 
 #include "io_static.c"
 
@@ -23,7 +20,7 @@ int  viahwm_base = -1;
 static int ReadByte(int addr)
 {
 	int ret;
-	ret = inb(viahwm_base + addr); WAIT;
+	ret = INb(viahwm_base + addr); WAIT;
 	return (ret & 0xFF);
 }
 
@@ -35,7 +32,7 @@ static void WriteByte(int addr, int value)
 static int ReadWord(int addr)
 {
 	int ret;
-	ret = inw(viahwm_base + addr); WAIT;
+	ret = INw(viahwm_base + addr); WAIT;
 	return (ret & 0xFFFF);
 }
 
