@@ -833,15 +833,21 @@ void init_dt(void)
 		iir_reg[i] = 0;
 }
 
+#define	THREDMAX	1.5
+#define	THREDMIN	0.5
 void alarm_handler(void)
 {
 	float d, *p;
 	int i, id, n;
-	float temp_in[4];
+	float temp_in[4], tpd[4];
 
+	getTemp(&tpd[0], &tpd[1], &tpd[2]);
+	getVolt(&tpd[3], &d, &d, &d, &d, &d, &d);
 	if (t_msec <= 1000){
-		getTemp(&temp_in[0], &temp_in[1], &temp_in[2]);
-		getVolt(&temp_in[3], &d, &d, &d, &d, &d, &d);
+		for (i = 0; i < NUM_DATA; i++) {
+			if (THREDMIN < tpd[i]/cur_val[i] && tpd[i]/cur_val[i] < THREDMAX)
+				temp_in[i] = tpd[i];
+		}
 			/* apply 2nd order IIR LPF, by Takayuki Hosoda */
 		for (i = 0; i < NUM_DATA; i++) {
 			d = iir_reg[i];
@@ -849,8 +855,10 @@ void alarm_handler(void)
 			cur_val[i] -= d * iir_tc;
 		}
 	} else {
-		getTemp(&cur_val[0], &cur_val[1], &cur_val[2]);
-		getVolt(&cur_val[3], &d, &d, &d, &d, &d, &d);
+		for (i = 0; i < NUM_DATA; i++) {
+			if (THREDMIN < tpd[i]/cur_val[i] && tpd[i]/cur_val[i] < THREDMAX)
+				cur_val[i] = tpd[i];
+		}
 	}
 
 	draw_values();
